@@ -2,6 +2,7 @@ __all__ = (
     "AuthController",
     "Authenticator",
     "AuthMessage",
+    "Config",
     "generate_certs",
     "smtpd",
     "SMTPDFix",
@@ -9,6 +10,9 @@ __all__ = (
 
 from .authenticator import Authenticator
 from .certs import generate_certs
+from .configuration import Config
 from .controller import AuthController
 from .fixture import SMTPDFix, smtpd
 from .handlers import AuthMessage
+
+config = Config()
