@@ -1,3 +1,5 @@
+import os
+from collections import namedtuple
 from email.message import EmailMessage
 
 import pytest
@@ -17,16 +19,6 @@ def pytest_collection_modifyitems(items):
             item.add_marker(pytest.mark.timeout(timeout_secs))
 
 
-@pytest.fixture
-def mock_smtpd_port(monkeypatch):
-    monkeypatch.setenv("SMTPD_PORT", "5025")
-
-
-@pytest.fixture
-def mock_smtpd_use_ssl(monkeypatch):
-    monkeypatch.setenv("SMTPD_USE_SSL", "True")
-
-
 @pytest.fixture
 def msg():
     msg = EmailMessage()
@@ -35,3 +27,11 @@ def msg():
     msg["To"] = "to.addr@example.org"
     msg.set_content("foo bar")
     return msg
+
+
+@pytest.fixture
+def user():
+    user = namedtuple("User", "username, password")
+    user.username = os.getenv("SMTPD_USERNAME", "user")
+    user.password = os.getenv("SMTPD_PASSWORD", "password")
+    return user
